==> V01.04.zip: tweet_live-V01.04/web/2011-2012-museo-desir/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '29.11.2011',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => array("fr" => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						  "en" => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						  "jp" => "Muséologie, muséographie et nouvelles formes d’adresse au public"),
						
   	'abstract'   => array(
    	"fr" 	 => "«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)",
       	"en" 	 => '«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)',
       	"jp" 	 => "«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)",
    ),

   	'description'=> array(
    	"fr" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
		
     	"en" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
		
     	"jp" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
    ),

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, web, web semantique, web social, iri',
   	'rep' 		 => basename('__DIR__'),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => array(
    		   "fr" => "images/big_visuel_museo_2011_fr.png",
    		   "en" => "images/big_visuel_museo_2011_fr.png",
    		   "jp" => "images/big_visuel_museo_2011_fr.png",
    ), // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => array(
    			  "fr" => "images/slide4_museo_fr.png",
    			  "en" => "images/slide4_museo_fr.png",
    			  "jp" => "images/slide4_museo_fr.png",
    ), // 606 × 282 pixels
    
  	'archive_img' => array(
    "fr" => "images/museo-2011.jpg",
    "en" => "images/museo-2011.jpg",
    "jp" => "images/museo-2011.jpg",
    ), // 270 × 150 pixels

 	'archive_title' => array("fr" => "Muséologie 2011 - Économie du désir et de la contribution", "en" => "Muséologie 2011 - Économie du désir et de la contribution", "jp" => "Muséologie 2011 - Économie du désir et de la contribution"),
 	'archive_description' => array(
 		"fr" => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 29 novembre 2011 | 17:00 - 20:00",
        "en" => "by <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> at the Centre Pompidou<br/> Tue, Nov. 29, 2011 | 17:00 - 20:00",
        "jp" => "主催: <a href=\"http:/www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> at the Centre Pompidou<br/> Tue, Nov. 29, 2011 | 17:00 - 20:00",
    ),

    // After the event
	'metadata'		=> "http://www.iri.centrepompidou.fr/dev/ldt/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);

==> V01.05.zip: tweet_live-V01.05/web/2011-2012-museo-desir/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '29.11.2011',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => array("fr" => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						  "en" => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						  "jp" => "Muséologie, muséographie et nouvelles formes d’adresse au public"),
						
   	'abstract'   => array(
    	"fr" 	 => "«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)",
       	"en" 	 => '«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)',
       	"jp" 	 => "«&nbsp;<b>Économie du désir, économie de la contribution.</b>&nbsp;» <br/>29 / 11 / 2011 de 17h00 à 20h00 @ Centre Pompidou (Paris)",
    ),

   	'description'=> array(
    	"fr" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
		
     	"en" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
		
     	"jp" 	 => "<b>Économie du désir, économie de la contribution.</b> (le 29/11/2011)<br/>
Dynamiques anthropologiques et processus d’individuation psychique et collective. Les institutions et espaces numériques construits sur la pratique amateur.<br/>
<ul>
  <li>Bernard Stiegler, IRI</li>
  <li>Michaël Vicente, UTC, M@rsouin,</li>
  <li>Jean-Louis Jam, Université Blaise Pascal (Clermont-Ferrand II)</li>
</ul>
Coups de projecteurs<br/>
<ul>
  <li>Goetz Bachman, l’exemple de Nico Nico Douga – Goldsmiths, Univ. de Londres</li>
  <li>Jean-Yves de Lépinay, Mashup Festival – Forum des images.</li>
</ul>",
    ),

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, web, web semantique, web social, iri',
   	'rep' 		 => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => array(
    		   "fr" => "images/big_visuel_museo_2011_fr.png",
    		   "en" => "images/big_visuel_museo_2011_fr.png",
    		   "jp" => "images/big_visuel_museo_2011_fr.png",
    ), // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => array(
    			  "fr" => "images/slide4_museo_fr.png",
    			  "en" => "images/slide4_museo_fr.png",
    			  "jp" => "images/slide4_museo_fr.png",
    ), // 606 × 282 pixels
    
  	'archive_img' => array(
    "fr" => "images/museo-2011.jpg",
    "en" => "images/museo-2011.jpg",
    "jp" => "images/museo-2011.jpg",
    ), // 270 × 150 pixels

 	'archive_title' => array("fr" => "Muséologie 2011 - Économie du désir et de la contribution", "en" => "Muséologie 2011 - Économie du désir et de la contribution", "jp" => "Muséologie 2011 - Économie du désir et de la contribution"),
 	'archive_description' => array(
 		"fr" => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 29 novembre 2011 | 17:00 - 20:00",
        "en" => "by <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> at the Centre Pompidou<br/> Tue, Nov. 29, 2011 | 17:00 - 20:00",
        "jp" => "主催: <a href=\"http:/www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> at the Centre Pompidou<br/> Tue, Nov. 29, 2011 | 17:00 - 20:00",
    ),

    // After the event
	'metadata'		=> "http://www.iri.centrepompidou.fr/dev/ldt/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);
